<?php
/**
 * The Header for our theme.
 */

global $THEMEREX_GLOBALS;

// Theme init - don't remove next row! Load custom options
themerex_core_init_theme();

$theme_skin = sanitize_file_name('alliance');
$blog_style = themerex_get_custom_option(is_singular() && !themerex_get_global('blog_streampage') ? 'single_style' : 'blog_style');
$body_style  = themerex_get_custom_option('body_style');
$logo_style = 'dark';
$article_style = themerex_get_custom_option('article_style');
$top_panel_style = 'dark';
$top_panel_opacity = 'solid';
$top_panel_position = 'over';
$video_bg_show  = themerex_get_custom_option('show_video_bg')=='yes' && (themerex_get_custom_option('video_bg_youtube_code')!='' || themerex_get_custom_option('video_bg_url')!='');
$page_icon = (is_404() ? 'icon-404' : themerex_get_custom_option('icon'));

$is_press = false;
if(function_exists('bp_current_component'))
	if(bp_current_component()) $is_press = true;
	
if(function_exists('is_bbpress'))
	if(is_bbpress()) $is_press = true;
	
	
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<?php
	wp_head();
	?>
</head>

<?php
	$class = $style = '';
		if(($img = themerex_get_custom_option('bg_custom_image')) != '')
			$style = 'background: url('.esc_url($img).') ' . str_replace('_', ' ', themerex_get_custom_option('bg_custom_image_position')) . ' no-repeat; background-size: cover; ';
		else if (($img = themerex_get_custom_option('bg_custom_pattern')) != '')
				$style = 'background: url('.esc_url($img).') 0 0 repeat;';
		else if (($img = themerex_get_custom_option('bg_pattern')) > 0)
				$class = 'bg_pattern_'.($img);
		else if (($img = themerex_get_custom_option('bg_color')) != '')
				$style .= 'background-color: '.($img).';'	
?>

<body <?php 
	body_class();
	?>
>
<?php wp_body_open(); ?>
	<?php themerex_show_layout(themerex_get_custom_option('gtm_code')); ?>

	<?php do_action( 'before' ); ?>

	<div class="body_wrap">

		<?php
		if ($video_bg_show) {
			$youtube = themerex_get_custom_option('video_bg_youtube_code');
			$video   = themerex_get_custom_option('video_bg_url');
			$overlay = themerex_get_custom_option('video_bg_overlay')=='yes';
			if (!empty($youtube)) {
				?>
				<div class="video_bg<?php themerex_show_layout($overlay ? ' video_bg_overlay' : ''); ?>" data-youtube-code="<?php echo esc_attr($youtube); ?>"></div>
				<?php
			} else if (!empty($video)) {
				$info = pathinfo($video);
				$ext = !empty($info['extension']) ? $info['extension'] : 'src';
				?>
				<div class="video_bg<?php echo esc_attr($overlay) ? ' video_bg_overlay' : ''; ?>"><video class="video_bg_tag" width="1280" height="720" data-width="1280" data-height="720" data-ratio="16:9" preload="metadata" autoplay loop src="<?php echo esc_url($video); ?>"><source src="<?php echo esc_url($video); ?>" type="video/<?php echo esc_attr($ext); ?>"></source></video></div>
				<?php
			}
		}	
		?>

		<div class="page_wrap <?php themerex_show_layout($class!='' ? ' ' . esc_attr($class) : ''); ?>" <?php themerex_show_layout($style!='' ? ' style="'.esc_attr($style).'"' : ''); ?>>

			<?php
			// Top panel and Slider
			if (in_array($top_panel_position, array('above', 'over'))) { require_once( themerex_get_file_dir('templates/parts/top-panel.php') ); }
			require_once( themerex_get_file_dir('templates/parts/slider.php') );
			if ($top_panel_position == 'below') { require_once( themerex_get_file_dir('templates/parts/top-panel.php') ); }

			// Top of page section: page title and breadcrumbs
			
			$header_style = '';
			if ($top_panel_style=='light') {
				$header_image2 = get_header_image();
				$header_color = themerex_get_custom_option('show_page_top') == 'yes' ? apply_filters('themerex_filter_get_link_color', themerex_get_custom_option('top_panel_bg_color')) : '';
				if (empty($header_image2) && file_exists(themerex_get_file_dir('skins/'.($theme_skin).'/images/bg_over.png'))) {
					$header_image2 = themerex_get_file_url('skins/'.($theme_skin).'/images/bg_over.png');
				}
				if ($header_image2!='' || $header_color != '') { 
					$header_style = ' style="' . ($header_image2!='' ? 'background-image: url('.esc_url($header_image2).'); background-repeat: repeat-x; background-position: center top;' : '') . ($header_color ? ' background-color:'.esc_attr($header_color).';' : '') . '"';
				}
			}
			if (themerex_get_custom_option('show_page_top') == 'yes' || is_404()) {
				$show_title = themerex_get_custom_option('show_page_title')=='yes' && !is_home() && !is_front_page();
				$show_breadcrumbs = themerex_get_custom_option('show_breadcrumbs')=='yes' && !is_home() && !is_front_page();
				?>
				<div class="page_top_wrap<?php themerex_show_layout(($show_title ? ' page_top_title' : '') . ($show_breadcrumbs ? ' page_top_breadcrumbs' : '')); ?>"<?php themerex_show_layout($header_style); ?>>
					<div class="content_wrap">
						<?php if ($show_breadcrumbs) { ?>
							<div class="breadcrumbs">
								<?php if (!is_404()) themerex_show_breadcrumbs(); ?>
							</div>
						<?php } ?>
						<?php if ($show_title) {?>
							<h5 class="page_title"><?php themerex_show_layout($page_icon != '' ? '<span class="page_icon '.$page_icon.'"></span>' : ''); echo wp_kses_post(themerex_get_blog_title()); ?></h5>
						<?php } ?>
					</div>
				</div>
			<?php
			}
			?>

			<div class="page_content_wrap" <?php echo (themerex_get_custom_option('show_page_top') == 'no' ? ' ' . trim($header_style) : ''); ?>>

				<?php
				// Content and sidebar wrapper
				if ($body_style!='fullscreen') themerex_open_wrapper('<div class="content_wrap">');
				
				// Main content wrapper
				themerex_open_wrapper('<div class="content">');
				?>