<?php
/**
 * Plugin support: WooCommerce
 *
 * @package WordPress
 * @subpackage ThemeREX Addons
 * @since v1.5
 */

// Check if plugin installed and activated

if ( !function_exists( 'trx_addons_exists_event_organiser' ) ) {
	function trx_addons_exists_event_organiser() {
		return defined('EVENT_ORGANISER_VER');
	}
}



// One-click import support
//------------------------------------------------------------------------

// Check plugin in the required plugins
if ( !function_exists( 'trx_addons_event_organiser_importer_required_plugins' ) ) {
	if (is_admin()) add_filter( 'trx_addons_filter_importer_required_plugins',	'trx_addons_event_organiser_importer_required_plugins', 10, 2 );
	function trx_addons_event_organiser_importer_required_plugins($not_installed='', $list='') {
		if (strpos($list, 'event-organiser')!==false && !trx_addons_exists_event_organiser() )
			$not_installed .= '<br>' . esc_html__('Event Organiser', 'trx_addons');
		return $not_installed;
	}
}

// Set plugin's specific importer options
if ( !function_exists( 'trx_addons_event_organiser_importer_set_options' ) ) {
	if (is_admin()) add_filter( 'trx_addons_filter_importer_options',	'trx_addons_event_organiser_importer_set_options' );
	function trx_addons_event_organiser_importer_set_options($options=array()) {
		if ( trx_addons_exists_event_organiser() && in_array('event-organiser', $options['required_plugins']) ) {
			if (is_array($options['files']) && count($options['files']) > 0) {
				foreach ($options['files'] as $k => $v) {
					$options['files'][$k]['file_with_event-organiser'] = str_replace('name.ext', 'event-organiser.txt', $v['file_with_']);
				}
			}
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'trx_addons_event_organiser_importer_show_params' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_params',	'trx_addons_event_organiser_importer_show_params', 10, 1 );
	function trx_addons_event_organiser_importer_show_params($importer) {
		if ( trx_addons_exists_event_organiser() && in_array('event-organiser', $importer->options['required_plugins']) ) {
			$importer->show_importer_params(array(
				'slug' => 'event-organiser',
				'title' => esc_html__('Import Event Organiser', 'trx_addons'),
				'part' => 1
			));
		}
	}
}

// Import posts
if ( !function_exists( 'trx_addons_event_organiser_importer_import' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_import',	'trx_addons_event_organiser_importer_import', 10, 2 );
	function trx_addons_event_organiser_importer_import($importer, $action) {
		if ( trx_addons_exists_event_organiser() && in_array('event-organiser', $importer->options['required_plugins']) ) {
			if ( $action == 'import_event-organiser' ) {
				$importer->response['start_from_id'] = 0;
				$importer->import_dump('event-organiser', esc_html__('Event Organiser', 'trx_addons'));
			}
		}
	}
}

// Display import progress
if ( !function_exists( 'trx_addons_event_organiser_importer_import_fields' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_import_fields',	'trx_addons_event_organiser_importer_import_fields', 10, 1 );
	function trx_addons_event_organiser_importer_import_fields($importer) {
		if ( trx_addons_exists_event_organiser() && in_array('event-organiser', $importer->options['required_plugins']) ) {
			$importer->show_importer_fields(array(
				'slug'=>'event-organiser',
				'title' => esc_html__('Event Organiser', 'trx_addons')
				)
			);
		}
	}
}

// Export posts
if ( !function_exists( 'trx_addons_event_organiser_importer_export' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_export',	'trx_addons_event_organiser_importer_export', 10, 1 );
	function trx_addons_event_organiser_importer_export($importer) {
		if ( trx_addons_exists_event_organiser() && in_array('event-organiser', $importer->options['required_plugins']) ) {
			trx_addons_fpc(TRX_ADDONS_PLUGIN_DIR . 'importer/export/event-organiser.txt', serialize( array(
				"eo_events"				=> $importer->export_dump("eo_events"),
				"eo_venuemeta"	                => $importer->export_dump("eo_events"),
				) )
			);
		}
	}
}

// Display exported data in the fields
if ( !function_exists( 'trx_addons_event_organiser_importer_export_fields' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_export_fields',	'trx_addons_event_organiser_importer_export_fields', 10, 1 );
	function trx_addons_event_organiser_importer_export_fields($importer) {
		if ( trx_addons_exists_event_organiser() && in_array('event-organiser', $importer->options['required_plugins']) ) {
			$importer->show_exporter_fields(array(
				'slug'	=> 'event-organiser',
				'title' => esc_html__('Event Organiser', 'trx_addons')
				)
			);
		}
	}
}
?>