<?php
/**
 * Plugin support: WooCommerce
 *
 * @package WordPress
 * @subpackage ThemeREX Addons
 * @since v1.5
 */

// Check if plugin installed and activated

if ( !function_exists( 'trx_addons_exists_wp_pro_quiz' ) ) {
	function trx_addons_exists_wp_pro_quiz() {
		return defined('WPPROQUIZ_VERSION');
	}
}


// One-click import support
//------------------------------------------------------------------------

// Check plugin in the required plugins
if ( !function_exists( 'trx_addons_wp_pro_quiz_importer_required_plugins' ) ) {
	if (is_admin()) add_filter( 'trx_addons_filter_importer_required_plugins',	'trx_addons_wp_pro_quiz_importer_required_plugins', 10, 2 );
	function trx_addons_wp_pro_quiz_importer_required_plugins($not_installed='', $list='') {
		if (strpos($list, 'wp-pro-quiz')!==false && !trx_addons_exists_wp_pro_quiz() )
			$not_installed .= '<br>' . esc_html__('WP-Pro-Quiz', 'trx_addons');
		return $not_installed;
	}
}

// Set plugin's specific importer options
if ( !function_exists( 'trx_addons_wp_pro_quiz_importer_set_options' ) ) {
	if (is_admin()) add_filter( 'trx_addons_filter_importer_options',	'trx_addons_wp_pro_quiz_importer_set_options' );
	function trx_addons_wp_pro_quiz_importer_set_options($options=array()) {
		if ( trx_addons_exists_wp_pro_quiz() && in_array('wp-pro-quiz', $options['required_plugins']) ) {
			if (is_array($options['files']) && count($options['files']) > 0) {
				foreach ($options['files'] as $k => $v) {
					$options['files'][$k]['file_with_wp-pro-quiz'] = str_replace('name.ext', 'wp-pro-quiz.txt', $v['file_with_']);
				}
			}
		}
		return $options;
	}
}

// Add checkbox to the one-click importer
if ( !function_exists( 'trx_addons_wp_pro_quiz_importer_show_params' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_params',	'trx_addons_wp_pro_quiz_importer_show_params', 10, 1 );
	function trx_addons_wp_pro_quiz_importer_show_params($importer) {
		if ( trx_addons_exists_wp_pro_quiz() && in_array('wp-pro-quiz', $importer->options['required_plugins']) ) {
			$importer->show_importer_params(array(
				'slug' => 'wp_pro_quiz',
				'title' => esc_html__('Import WP-Pro-Quiz', 'trx_addons'),
				'part' => 1
			));
		}
	}
}

// Import posts
if ( !function_exists( 'trx_addons_wp_pro_quiz_importer_import' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_import',	'trx_addons_wp_pro_quiz_importer_import', 10, 2 );
	function trx_addons_wp_pro_quiz_importer_import($importer, $action) {
		if ( trx_addons_exists_wp_pro_quiz() && in_array('wp-pro-quiz', $importer->options['required_plugins']) ) {
			if ( $action == 'import_wp_pro_quiz' ) {
				$importer->response['start_from_id'] = 0;
				$importer->import_dump('wp-pro-quiz', esc_html__('WP-Pro-Quiz', 'trx_addons'));
			}
		}
	}
}

// Export posts
if ( !function_exists( 'trx_addons_wp_pro_quiz_importer_export' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_export',	'trx_addons_wp_pro_quiz_importer_export', 10, 1 );
	function trx_addons_wp_pro_quiz_importer_export($importer) {
		if ( trx_addons_exists_wp_pro_quiz() && in_array('wp-pro-quiz', $importer->options['required_plugins']) ) {
			trx_addons_fpc(TRX_ADDONS_PLUGIN_DIR . 'importer/export/wp-pro-quiz.txt', serialize( array(
				"wp_pro_quiz_category"				=> $importer->export_dump("wp_pro_quiz_category"),
				"wp_pro_quiz_form"	                => $importer->export_dump("wp_pro_quiz_form"),
				"wp_pro_quiz_lock"					=> $importer->export_dump("wp_pro_quiz_lock"),
				"wp_pro_quiz_master"				=> $importer->export_dump("wp_pro_quiz_master"),
				"wp_pro_quiz_prerequisite"			=> $importer->export_dump("wp_pro_quiz_prerequisite"),
                "wp_pro_quiz_question"			    => $importer->export_dump("wp_pro_quiz_question"),
                "wp_pro_quiz_statistic"			    => $importer->export_dump("wp_pro_quiz_statistic"),
                "wp_pro_quiz_statistic_ref"			=> $importer->export_dump("wp_pro_quiz_statistic_ref"),
                "wp_pro_quiz_template"			    => $importer->export_dump("wp_pro_quiz_template"),
                "wp_pro_quiz_toplist"			    => $importer->export_dump("wp_pro_quiz_toplist")
				) )
			);
		}
	}
}

// Display exported data in the fields
if ( !function_exists( 'trx_addons_wp_pro_quiz_importer_export_fields' ) ) {
	if (is_admin()) add_action( 'trx_addons_action_importer_export_fields',	'trx_addons_wp_pro_quiz_importer_export_fields', 10, 1 );
	function trx_addons_wp_pro_quiz_importer_export_fields($importer) {
		if ( trx_addons_exists_wp_pro_quiz() && in_array('wp-pro-quiz', $importer->options['required_plugins']) ) {
			$importer->show_exporter_fields(array(
				'slug'	=> 'wp-pro-quiz',
				'title' => esc_html__('WP-Pro-Quiz', 'trx_addons')
				)
			);
		}
	}
}
?>